<?php

class DbProxy
{
	private $db;
	private $Config;
	private $Proxies;
	
	
	public function __construct() {
		$this->db = Db::Singleton();
		$this->Config = DbConfig::Singleton();
		$this->Proxies = array();
	}

	/**
	* @param int $PortionSize
	* @param bool[optional] $WorkedOnly - if TRUE will return worked proxies only
	* @return array of Proxy instances
	*/
	public function GetNextPortion($PortionSize, $WorkedOnly=false) {
		$this->db->Begin();

		if ($WorkedOnly) {
			$Seconds = $this->Config->GetParam('recheck_rate') * 60;
			$Where = 'worked=1 AND (UNIX_TIMESTAMP() - UNIX_TIMESTAMP(date_check)) > '.intval($Seconds).' ORDER BY date_check';
		} else {
			$Where = 'checked=0';
		}
		
		$this->db->Query('SELECT proxy, country, code_country FROM proxy WHERE '.$Where.' LIMIT 0,'.intval($PortionSize).' FOR UPDATE');
		$Rows = $this->db->FetchRows();
		
		if (empty($Rows)) {
			$this->db->Commit();
			return array();
		}
		
		$pr = array();
		$this->Proxies = array();
		foreach ($Rows as $v) {
			$pr[] = addslashes($v['proxy']);
			$this->Proxies[] = new ProxyChecker($v['proxy'], $v['country'], $v['code_country']);
		}
		
		$this->db->Query("UPDATE proxy SET checked=1 WHERE proxy IN('".implode("',\r\n'",$pr)."')");
		$this->db->Commit();
		return $this->Proxies;
	}
	
	/**
	* Save proxies to database
	* @param bool[optional] $DeleteUnworked - if FALSE proxy will be only moved to unchecked base
	*/
	public function Save($DeleteUnworked=true) {
		$Unworked = array();
		$Worked = array();
		foreach ($this->Proxies as $v) {
			if ($v->GetWorked()) $Worked[] = $v;
			else $Unworked[] = addslashes($v->GetProxy());
		}
		
		// Delete unworked
		if (!empty($Unworked)) {
			if ($DeleteUnworked) {
				$this->db->Query("DELETE FROM proxy WHERE proxy IN('".implode("',\r\n'", $Unworked)."')");
			} else {
				$this->db->Query("UPDATE proxy SET worked=0, checked=0 WHERE proxy IN('".implode("',\r\n'", $Unworked)."')");
			}
		}
		
		// Save worked
		foreach ($Worked as $v) {
			
			// Delete transparent
			if ($this->Config->GetParam('anon_only') && $v->GetAnon()==0) {
				$this->db->Query("DELETE FROM proxy WHERE proxy='".addslashes($v->GetProxy())."'");
				continue;
			}
			
			if ($v->GetCountry() || $v->GetCodeCountry()) {
				$Country = " country='".addslashes($v->GetCountry())."',"
					. " code_country='".addslashes($v->GetCodeCountry())."',";
			} else {
				$Country = '';
			}
			$this->db->Query('UPDATE proxy SET'
				. " worked=1,"
				. " contime=".doubleval($v->GetContime()).","
				. " time=".doubleval($v->GetTime()).","
				. " speed=".intval($v->GetSpeed()).","
				. " post=".intval($v->GetPost()).","
				. " referer=".intval($v->GetReferer()).","
				. " cookies=".intval($v->GetCookies()).","
				. " anon=".intval($v->GetAnon()).","
				. $Country
				. " code_curl=".intval($v->GetErrno()).","
				. " code_http=".intval($v->GetHttpCode()).","
				. " date_check=NOW(),"
				. " uptime = UNIX_TIMESTAMP() - UNIX_TIMESTAMP(date_add)"
				. " WHERE proxy='".addslashes($v->GetProxy())."'");
		}
	}
	
	
	
	
	public static function GetUncheckedCount() {
		$db = Db::Singleton();
		$db->Query('SELECT COUNT(*) FROM proxy WHERE checked=0');
		return intval($db->FetchCell());
	}

	public static function GetCheckedCount() {
		$db = Db::Singleton();
		$db->Query('SELECT COUNT(*) FROM proxy WHERE checked=1');
		return intval($db->FetchCell());
	}
}

?>