<?php
class Pager
{
	private $ItemsCount;
	private $PagesCount;
	private $PerPage;
	private $CurrentPage;
	
	
	
	
	function __construct($ItemsCount=0, $PerPage=0) {
		$this->SetItemsCount($ItemsCount);
		$this->SetPerPage($PerPage);
		$this->SetPage(1);
	}
	
	public function SetItemsCount($Count) {
		$this->ItemsCount = $this->Positive($Count);
		$this->PagesCount = $this->GetPagesCount();
		$this->CurrentPage = $this->RealPage($this->CurrentPage);
	}
	
	public function SetPerPage($Count) {
		$this->PerPage = $this->Positive($Count);
		$this->PagesCount = $this->GetPagesCount();
	}
	
	public function SetPage($Page) {
		$this->CurrentPage = $this->RealPage($Page);
	}
	
	public function SetPageByItem($ItemNumber) {
		if($this->PerPage == 0) return;
		$this->CurrentPage = $this->RealPage( floor($ItemNumber / $this->PerPage) + 1 );
	}
	

	

	
	public function GetPagesCount() {
		if($this->PerPage == 0) return 0;
		return ceil( $this->ItemsCount / $this->PerPage );
	}
	
	public function GetPageInfo($Page) {
		$Page = intval($Page);
		if( !$this->IsPageExist($Page) ) return false;
		return array(
			'Page' => $Page,
			'FirstItem' => $this->GetFirstItem($Page),
			'LastItem' => $this->GetLastItem($Page),
			'IsFirstPage' => !$this->IsPageExist($Page-1),
			'IsLastPage' => !$this->IsPageExist($Page+1),
			'IsCurrentPage' => $Page == $this->CurrentPage			
			);
	}
	
	public function GetPagesInfo($MaxDisplayPages=0, $ShowSinglePage=false) {
		list($FirstPage, $LastPage) = $this->MakePagesDiapason($MaxDisplayPages);
		
		$Pages = array();
		if($this->PagesCount == 0) return $Pages;
		if($this->PagesCount == 1
		&& $ShowSinglePage == false) return $Pages;
			
		for($i=$FirstPage; $i<=$LastPage; $i++) {
			$Pages[$i] = $this->GetPageInfo($i);
		}
		
		return $Pages;
	}

	public function GetInfo() {
		return array(
			'ItemsCount'			=> $this->ItemsCount,
			'PerPage'				=> $this->PerPage,
			'CurrentPage'			=> $this->CurrentPage,
			'PagesCount'			=> $this->PagesCount,
			'IsFirstPageSelected'	=> !$this->IsPageExist($this->CurrentPage - 1),
			'IsLastPageSelected'	=> !$this->IsPageExist($this->CurrentPage + 1),
			'CurrentPageInfo'		=> $this->GetPageInfo($this->CurrentPage),
			'PreviousPageInfo'		=> $this->GetPageInfo($this->CurrentPage - 1),
			'NextPageInfo'			=> $this->GetPageInfo($this->CurrentPage + 1),
			'FirstPageInfo' 		=> $this->GetPageInfo(1),
			'LastPageInfo'			=> $this->GetPageInfo($this->PagesCount)
			);
	}
	
	
	
	
	
	public function GetFirstItem($Page=null) {
		if($Page === null) $Page = $this->CurrentPage;
		$Page = $this->RealPage($Page);
		return $this->Positive( ($Page - 1) * $this->PerPage );
	}

	public function GetLastItem($Page=null) {
		$FirstItem = $this->GetFirstItem($Page);
		$LastItem = $FirstItem + $this->Positive($this->PerPage - 1);		
		if ($LastItem > $this->ItemsCount) {
			$LastItem = $this->Positive($this->ItemsCount - 1);
		}
		return $LastItem;
	}
	
	
	
	

	public function GetItemsCount() {
		return $this->ItemsCount;
	}

	public function GetPerPage() {
		return $this->PerPage;
	}
	
	public function GetPage() {
		return $this->CurrentPage;
	}
	
	public function IsPageExist($Page) {
		return intval($Page) == $this->RealPage($Page);				
	}
	
	

	
	/**
	* PRIVATE PART
	*/
	
	private function RealPage($Page) {
		$Page = intval($Page);
		if($Page < 1) $Page = 1;
		if($Page > $this->PagesCount) $Page = $this->PagesCount;
		return $Page;
	}

	private function Positive($Value) {
		$Value = intval($Value);
		return ($Value < 0) ? 0 : $Value;
	}
	
	private function MakePagesDiapason($MaxDisplayPages=0) {
		$MaxDisplayPages = $this->Positive($MaxDisplayPages);
		if ($MaxDisplayPages !== 0
		&&  $MaxDisplayPages < $this->PagesCount)
		{
			// SHOW PAGES DIAPASON
			$FirstPage = $this->RealPage( $this->CurrentPage - floor($MaxDisplayPages/2) );
			$LastPage = $FirstPage + $MaxDisplayPages - 1;
			if($LastPage > $this->PagesCount) {
				$LastPage = $this->PagesCount;
				$FirstPage = $LastPage - $MaxDisplayPages + 1;
			}
		} else {
			// SHOW ALL PAGES
			$FirstPage = 1;
			$LastPage = $this->PagesCount;
		}
		return array($FirstPage, $LastPage);
	}
}
?>