<?php

class Table
{
	private $Skin;
	private $Pager;
	private $DisplayHeader;
	private $DisplayPages;
	private $Cols;
	private $Order;
	private $Direction;
	private $Rows;

	
	
	public function __construct($TotalRowsCount=null) {
		$this->Pager = new Pager(0, CONF_ITEMS_PER_PAGE);
		$this->AcceptSkin(Dispatcher::Singleton()->GetSkin());
		$this->DisplayHeader = true;
		$this->DisplayPages = true;
		$this->Cols = array();
		$this->Order = null;
		$this->Direction = 'asc';
		$this->Rows = array();
		if ($TotalRowsCount!==null) $this->SetRowsCount($TotalRowsCount);
	}

	
	
	
	
	public function DisplayHeader($OnOff) {
		$this->DisplayHeader = $OnOff ? true : false;
	}

	public function DisplayPages($OnOff) {
		$this->DisplayPages = $OnOff ? true : false;
	}
	
	public function AddColumn($Key, $Name=null, $Sortable=true, $TagParams='', $Template='{$item|escape}') {
		if ($Name===null) $Name = $Key;
		if (is_array($Name)) {$HeadParams = $Name[0]; $Name = $Name[1];}
		else $HeadParams = null;
		$this->Cols[$Key] = array('key'=>$Key, 'head_params'=>$HeadParams, 'name'=>$Name, 'sortable'=>$Sortable, 'tag_params'=>$TagParams, 'template'=>$Template);
	}
	
	public function RemoveColumn($Key) {
		unset($this->Cols[$Key]);
	}
	
	public function AutoColumns($Sortable=true, $TagParams='', $Template='{$item|escape}') {
		$Row = @reset($this->Rows);
		if (is_array($Row)) {
			foreach ($Row as $k=>$v) {
				if (!isset($this->Cols[$k])) $this->AddColumn($k, $k, $Sortable, $TagParams, $Template);
			}
		}
	}
	
	public function LoadStateFrom(&$State) {
		if (isset($State['p'])) $this->SetPage($State['p']);
		if (isset($State['o'])) $this->SetOrder($State['o']);
		if (isset($State['d'])) $this->SetDirection($State['d']);
	}

	public function SaveStateTo(&$State) {
		$State['p'] = $this->GetPage();
		$State['o'] = $this->GetOrder();
		$State['d'] = $this->GetDirection();
	}

	
	
	
	
	

	public function SetRowsCount($Count) {
		$this->Pager->SetItemsCount($Count);
		$this->LoadStateFrom($_GET);		
	}
	
	public function SetPage($Page) {
		$this->Pager->SetPage($Page);
	}
	
	public function SetOrder($ColumnName) {
		$this->Order = $ColumnName;
	}
	
	public function SetDirection($Dir) {
		$Dir = strtolower($Dir);
		if ($Dir=='asc' || $Dir=='desc') $this->Direction = $Dir;
		else trigger_error("Direction must be 'asc' or 'desc'", E_USER_NOTICE);
	}
	
	/**
	* Set rows set for display
	* @param array $Rows - array(array('field_name'=>'field_value'), ...)
	*/
	public function SetRows(&$Rows) {
		if (is_array($Rows)) $this->Rows =& $Rows;
		else trigger_error('Array is expected', E_USER_WARNING);
	}
	
	
	
	
	
	
	
	public function GetRowsCount() {
		return $this->Pager->GetItemsCount();
	}

	public function GetPager() {
		return $this->Pager;
	}
	
	public function GetPage() {
		return $this->Pager->GetPage();
	}
	
	public function GetOrder() {
		return $this->Order;
	}
	
	public function GetDirection() {
		return $this->Direction;
	}
	
	public function GetLimitStart() {
		return $this->Pager->GetFirstItem();
	}
	
	public function GetLimitOffset() {
		return $this->Pager->GetPerPage();
	}
	
	public function GetSqlOrder() {
		if (empty($this->Order)) return '';
		return 'ORDER BY '.addslashes($this->GetOrder()).' '.addslashes(strtoupper($this->GetDirection()));
	}
	
	public function GetSqlLimit() {
		return 'LIMIT '.intval($this->GetLimitStart()).','.intval($this->GetLimitOffset());
	}
	
	public function GetSql() {
		return $this->GetSqlOrder().' '.$this->GetSqlLimit();
	}
		
	public function IsEmpty() {
		return !$this->GetRowsCount();
	}	
	
	
	
	
	public function AcceptSkin($Skin) {
		if ($Skin instanceof Skin) {
			$this->Skin = $Skin;
		} 
		else trigger_error('Skin object expected', E_USER_WARNING);
	}
	
	public function display() {
		$Rend = $this->ToArray();
		$this->Skin->assign('Rend', $Rend);
		$this->Skin->display('Table.tpl');
	}
	
	
	
	
	public function ToArray() {
		// array for header and rows display
		$Rend['cols'] = $this->Cols;
		$Rend['rows'] = $this->Rows;
		
		// make link for table actions
		$Module = Dispatcher::Singleton()->GetModuleName();
		$Action = Dispatcher::Singleton()->GetActionName();
		$Get = $_GET;
		unset($Get['p'], $Get['o'], $Get['d']);
		$Query = http_build_query($Get);
		if (!empty($Query)) $Query .= '&';
		if (!empty($Module)	&& !empty($Action))	$Rend['link'] = $Module.'/'.$Action.'/?'.$Query;
		else									$Rend['link'] = $_SERVER['PHP_SELF'].'?'.$Query;
		
		$Rend['link_p'] = $this->GetPage();
		$Rend['link_o'] = $this->GetOrder();
		$Rend['link_d'] = $this->GetDirection();
		$Rend['link_d_reverse'] = $Rend['link_d']=='asc' ? 'desc' : 'asc';

		// display
		$Rend['display_header'] = $this->DisplayHeader;
		$Rend['display_pages'] = $this->DisplayPages;
		
		// make pager array
		$Rend['navigator'] = $this->Pager->GetInfo();
		$Rend['pages'] = $this->Pager->GetPagesInfo(CONF_MAX_DISPLAY_PAGES);
			
		return $Rend;
	}
}

?>