<?php

class DebugLogger
{
	private static $Instance;
	private $Operations;
	private $FileName;
	
	
	
	
	public static function Singleton() {
		if( !isset(self::$Instance) ) {
			$ClassName = __CLASS__;
			self::$Instance = new $ClassName();
		}
		return self::$Instance;
	}
	
	public function __clone() {
		trigger_error('Clone is not allowed.', E_USER_ERROR);
	}
	
	private function __construct() {
		$this->Operations = array();
		$this->SetFileName('debug.srz');
	}
	
	
	
	


	public function SetFileName($FileName) {
		$this->FileName = $FileName;
		$this->Read();
	}
	
	public function GetFileName() {
		return $this->FileName;
	}
	
	public function GetDebugInfo() {
		return $this->Operations;
	}
	
	public static function GetDebugInfoFromExternalFile($FileName) {
		$File = CONF_DEBUG_DIR.$FileName;
		if (is_file($File)) {
			return unserialize( file_get_contents($File) );
		}
		return null;
	}

	
	
	

	
	public function AddMessage($Message) {
		$this->Operations[] = array(
			'Type'		=> 'Message',
			'Message'	=> $Message,
			'StartTime'	=> microtime(true),
			);
		$this->Write();
	}
	
	public function StartQuery($Query) {
		$this->Operations[] = array(
			'Type'		=> 'Query',
			'Query'		=> $Query,
			'Result'	=> null,
			'StartTime'	=> microtime(true),
			'EndTime'	=> null,
			'Duration'	=> null
			);
		$this->Write();
	}
	
	public function EndQuery($NumRows, $AffectedRows, $Info) {
		$Last =& $this->GetLastOperationLink();
		if ($Last['Type'] == 'Query') {
			$Last['Result'] = array(
				'NumRows'		=> $NumRows,
				'AffectedRows'	=> $AffectedRows,
				'Info'			=> $Info,
				);
			$Last['EndTime'] = microtime(true);
			$Last['Duration'] = $Last['EndTime'] - $Last['StartTime'];
			$this->Write();
		}
	}
	
	public function Clear() {
		$this->Operations = array();
		$this->Write();		
	}	

	
	
	
	
	
	private function &GetLastOperationLink() {
		end($this->Operations);
		$Key = key($this->Operations);
		$Item =& $this->Operations[$Key];
		return $Item;
	}	
	
	private function Read() {
		$File = CONF_DEBUG_DIR.$this->FileName;
		if (is_file($File)) {
			$this->Operations = unserialize( file_get_contents($File) );
		} else {
			$this->Operations = array();
		}
	}
	
	private function Write() {
		file_put_contents(CONF_DEBUG_DIR.$this->FileName, serialize($this->Operations));
	}
}

?>