<?php

class FtpAccess
{
	private $Host;
	private $Port;
	private $User;
	private $Pass;
	
	private $Link;
	private $Connected;
	private $Timeout;
	private $Ssl;
	private $Error;
	
	
	public function __construct($Host, $Port=21, $User='Anonymous', $Pass='', $Timeout=30, $Ssl=false) {
		$this->Host = $Host;
		$this->Port = $Port;
		$this->User = $User;
		$this->Pass = $Pass;
		$this->Timeout = $Timeout;
		$this->Ssl = $Ssl;
		$this->Connect();		
	}
	
	public function __destruct() {
		$this->Disconnect();
	}
	
	
	
	
	
	public function IsConnected() {
		return $this->Connected;
	}
	
	public function Reconnect() {
		$this->Disconnect();
		$this->Connect();
	}
	
	public function Passive($State) {
		if (ftp_pasv($this->Link, $State) == false) return $this->Error('Cannot set passive mode');
		return $this->Ok();
	}
	
	public function ChangeDir($Directory) {
		if (@ftp_chdir($this->Link, $Directory) == false) return $this->Error('Cannot change directory');
		return $this->Ok();
	}
	
	public function Up() {
		if (ftp_cdup($this->Link) == false) return $this->Error('Cannot change to the parent directory');
		return $this->Ok();
	}
	
	/**
	* @param string $File - local file path
	* @param string[optional] $RemoteFile - remote file path
	* @param int[optional] $Mode - transfer mode, can be either FTP_ASCII or FTP_BINARY
	*/
	public function Upload($File, $RemoteFile=null, $Mode=FTP_BINARY) {
		if ($RemoteFile===null) $RemoteFile = basename($File);
		if (ftp_put($this->Link, $RemoteFile, $File, $Mode) == false) return $this->Error('Cannot upload file: '.$File);
		return $this->Ok();
	}
	
	
	
	
	
	public function GetError() {
		return $this->Error;
	}
	
	public function GetLink() {
		return $this->Link;
	}
	
	public function GetDir() {
		$Dir = ftp_pwd($this->Link);
		if ($Dir==false) return $this->Error('Cannot get current directory name');
		return $this->Ok($Dir);
	}
	
	public function GetList($Directory='.') {
		$List = ftp_nlist($this->Link, $Directory);
		if ($List==false) return $this->Error('Cannot get files list');
		return $this->Ok($List);
	}
	
	
	
	
	
	
	
	private function Connect() {
		$this->Link = $this->Ssl ?
			$this->Link = @ftp_ssl_connect($this->Host, $this->Port, $this->Timeout)
		:	@ftp_connect($this->Host, $this->Port, $this->Timeout);
		if ($this->Link == false) {
			$this->Error = 'Cannot connect to FTP server: '.$this->Host.':'.$this->Port;
			$this->Connected = false;
			return false;
		}
		if (@ftp_login($this->Link, $this->User, $this->Pass) == false) {
			$this->Error = 'Cannot login in to FTP server';
			$this->Connected = false;
			return false;
		}
		$this->Connected = true;
		return true;		
	}
	
	private function Disconnect() {
		if ($this->Link !== false) @ftp_close($this->Link);
	}
	
	private function Error($Message) {
		$this->Error = $Message;
		return false;
	}
	
	private function Ok($Return=true) {
		$this->Error = null;
		return $Return;
	}
}

?>