<?php
/**
 * Smarty plugin
 * @package Smarty
 * @subpackage plugins
 */

/**
 * Smarty CONDITION modifier plugin
 *
 * Type:     modifier<br>
 * Name:     condition<br>
 * Date:     2007-06-03
 * Purpose:  check variable for satisfy condition
 * @author	Razor (igshat@gawab.com)
 *
 * @param string $cond - condition (for example: 'form_checkbox[first]==Value')
 * @param mixed $var - variable for test
 * @param mixed[optional] $true - value that returns if condition satisfied 
 * @param mixed[optional] $false - value that returns if not condition satisfied
 */
function smarty_modifier_condition($cond, $var, $true=true, $false=false) 
{
	$m = null;
	
	// IS SET VARIABLE
	if (preg_match('#^[^\[\=]+$#', $cond, $m)) {
		$name = $m[0];
		return isset($var[$name]) ? $true : $false;
	}

	// IS VARIABLE EQUAL TO VALUE
	if (preg_match('#^([^\[\=]+)==(.*)$#', $cond, $m)) {
		$name = $m[1];
		$value = $m[2];
		if (isset($var[$name])) {
			return $var[$name] == $value ? $true : $false;
		}
		return $false;
	}
	
	// IS SET VARIABLE WITH SPECIFIED KEY
	if (preg_match('#^([^\[\=]+)\[(.+)]$#', $cond, $m)) {
		$name = $m[1];
		$key = $m[2];
		return isset($var[$name][$key]) ? $true : $false;
	}

	// IS VARIABLE WITH SPECIFIED KEY EQUAL TO VALUE
	if (preg_match('#^([^\[\=]+)\[(.+)]==(.*)$#', $cond, $m)) {
		$name = $m[1];
		$key = $m[2];
		$value = $m[3];
		if (isset($var[$name][$key])) {
			return $var[$name][$key] == $value ? $true : $false;
		}
		return $false;
	}

	// IS SET VARIABLE IN ARRAY
	if (preg_match('#^([^\[\=]+)\[]==(.*)$#', $cond, $m)) {
		$name = $m[1];
		$value = $m[2];
		if (isset($var[$name]) && is_array($var[$name])) {
			return in_array($value, $var[$name]) ? $true : $false;
		}
		return $false;
	}
	
	return null;
}

/* vim: set expandtab: */

?>